@@ -11,7 +11,6 @@
  * (at your option) any later version.
  */
 
-//##define _FILE_OFFSET_BITS 64
 #include <config.h>
 #define _LARGEFILE64_SOURCE
 #include <features.h>
@@ -82,6 +81,7 @@ extern void usage(void)
         "    -N,  --ncurses          Using Ncurses User Interface\n"
 #endif
         "    -X,  --dialog           output message as Dialog Format\n"
+        "    -F,  --force            force progress\n"
         "    -h,  --help             Display this help\n"
     , EXECNAME, VERSION, svn_version, EXECNAME);
     exit(0);
@@ -89,7 +89,7 @@ extern void usage(void)
 
 extern void parse_options(int argc, char **argv, cmd_opt* opt)
 {
-    static const char *sopt = "-hd::cbro:O:s:RCXN";
+    static const char *sopt = "-hd::cbro:O:s:RCXFN";
     static const struct option lopt[] = {
         { "help",		no_argument,	    NULL,   'h' },
         { "output",		required_argument,  NULL,   'o' },
@@ -102,6 +102,7 @@ extern void parse_options(int argc, char **argv, cmd_opt* opt)
         { "rescue",		no_argument,	    NULL,   'R' },
         { "check",		no_argument,	    NULL,   'C' },
         { "dialog",		no_argument,	    NULL,   'X' },
+        { "force",		no_argument,	    NULL,   'F' },
 #ifdef HAVE_LIBNCURSESW
         { "ncurses",		no_argument,	    NULL,   'N' },
 #endif
@@ -149,6 +150,9 @@ extern void parse_options(int argc, char **argv, cmd_opt* opt)
 		    else
 			opt->debug = 1;
                     break;
+	    case 'F':
+		    opt->force++;
+		    break;
 	    case 'R':
 		    opt->rescue++;
 		    break;
@@ -389,14 +393,16 @@ extern void log_mesg(int log_level, int log_exit, int log_stderr, int debug, con
 	}
     } else {
 	/// write log to stderr if log_stderr is true
-	if((log_stderr) && (log_level <= debug)){
-	    vfprintf(stderr, fmt, args);
+	if((log_stderr == 1) && (log_level <= debug)){
+	    vsprintf(tmp_str, fmt, args);
+	    fprintf(stderr, "%s", tmp_str);
 	}
     }
 
     /// write log to logfile if debug is true
     if(log_level <= debug){
-	vfprintf(msg, fmt, args);
+	vsprintf(tmp_str, fmt, args);
+	fprintf(msg, "%s", tmp_str);
 	//if (errno != 0)
 	//    fprintf(msg, "%s(%i), ", strerror(errno), errno);
     }
@@ -530,8 +536,9 @@ extern void get_image_bitmap(int* ret, cmd_opt opt, image_head image_hdr, char*
     int do_write = 0;
     char* buffer;
     unsigned long long block_id;
-    unsigned long bused = 0, bfree = 0;
+    unsigned long long bused = 0, bfree = 0;
     int debug = opt.debug;
+    int err_exit = 1;
 
     size = sizeof(char)*image_hdr.totalblock;
     buffer = (char*)malloc(size);
@@ -550,9 +557,15 @@ extern void get_image_bitmap(int* ret, cmd_opt opt, image_head image_hdr, char*
             bfree++;
 	}
     }
-    if(image_hdr.usedblocks != bused)
-        log_mesg(0, 1, 1, debug, "bitmap [used %li, and free %li] and image_head used %i is different\n", bused, bfree, image_hdr.usedblocks);
-    
+    if (debug >= 2) {
+	if(image_hdr.usedblocks != bused){
+	    if (opt.force)
+		err_exit = 0;
+	    else
+		err_exit = 1;
+	    log_mesg(0, err_exit, 1, debug, "The Used Block count is different.(bitmap %lli != image_head %lli)\nTry to use --force to skip the metadata error.\n", bused, image_hdr.usedblocks);
+	}	
+    } 
 }
 
 
